load VA_data.mat
VA_and_env = [va, lat, lon, z, t1,t2, zb]; 
% va: viral abundance in gVOD database(https://doi.org/10.1594/PANGAEA.915758) 
% lat, lon, z: coordiates in gVOD database
% t1,t2: continuous months following Tang et al. 2019 JGR 
% (doi:10.1029/2018JG004828)
% zb: bottom depth of sampling site from MATLAB topographic data (topo.mat)

valog = log10(VA_and_env(:,1));% VA is lognormal distribution.
VA_and_env(:,1) = valog;
qc = [0.5, 99.5]; % only keeps data within a certain range of prictiles
qcv = prctile(valog, qc);
idx = find(valog>=qcv(1)&valog<=qcv(2));
VA_and_env_qc = VA_and_env(idx, :);
%% 
[trainedModel, validationRMSE] = trainRegressionModel(VA_and_env_qc);
%% prepare input
zg = [0:25:100, 200:100:1000, 1200:200:7000];
z = 0.5 * (zg(1:end-1) + zg(2:end));
nz = length(z);
dz = diff(zg);
[lat3d, lon3d, z3d] = ndgrid(-89.5:89.5, -179.5:179.5, z);
mon3d = zeros(size(lat3d));
load topo
zb3d = repmat(topo, 1, 1, nz);
nanidx = find(-z3d<zb3d);
z3d(nanidx) = NaN;
lat3d(nanidx) = NaN;
lon3d(nanidx) = NaN;
mon3d(nanidx) = NaN;
zb3d(nanidx) = NaN;
%% predict
totva = zeros(12,1);
va3dmean = 0;
vafit1= zeros(180,360,43,12);
for imon = 1:12
    mon3d = mon3d * 0 + imon;
    t1 = cos(mon3d*2*pi/12);
    t2 = sin(mon3d*2*pi/12);
    vafit = trainedModel.predictFcn([lat3d(:), lon3d(:), z3d(:), t1(:),t2(:), zb3d(:)]);
    vafit = reshape(vafit, size(lat3d));
    vafit(nanidx) = NaN;
    vafit = 10.^vafit;
    vafit1(:,:,:,imon) = vafit;
    %% calculate total virus
    earthellipsoid = referenceSphere('earth','m');
    area = areaquad(lat3d-0.5, lon3d-0.5, lat3d+0.5, lon3d+0.5, earthellipsoid);
    vol = zeros(size(area));
    for iz = 1:nz
        vol(:,:,iz) = area(:,:,iz) * dz(iz);
    end
    totva3d = vafit * 1e6 .* vol;
    va3dmean = va3dmean + vafit;
    totva(imon) = nansum(totva3d(:));
end
totva_y = mean(totva);
setotva_y = std(totva)/sqrt(length(totva));